# numberwords.py
# --------------
# By MWC Contributors
# Functions to print out a verbal representation of an integer.

MAXIMUM = 1000000
DIGIT_NAMES = [
    "zero", "one", "two", "three", "four", "five", "six", "seven", "eight", "nine"
]
TWEEN_AND_TEEN_NAMES = [
    "ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen", "sixteen", "seventeen", "eighteen", "nineteen"
]
TENS_NAMES = [
    "", "ten", "twenty", "thirty", "forty", "fifty", "sixty", "seventy", "eighty", "ninety"
]

def int_under_1000000_to_str(number):
    if number < 1000:
        return int_under_1000_to_str(number)

    thousands, remainder = divide_with_remainder(number, 1000)
    thousands_part = f"{int_under_1000_to_str(thousands)} thousand"

    if remainder == 0:
        return thousands_part
    else:
        remainder_part = int_under_1000_to_str(remainder)
        return f"{thousands_part} and {remainder_part}"
        
def int_under_1000_to_str(number):
    if number < 100:
        return int_under_100_to_str(number)
    else:
        hundreds, remainder = divide_with_remainder(number, 100)
        if remainder == 0:
            return f"{int_under_10_to_str(hundreds)} hundred"
        else:
            return f"{int_under_10_to_str(hundreds)} hundred and {int_under_100_to_str(remainder)}"

def int_under_100_to_str(number):
    if number < 10:
        return int_under_10_to_str(number)
    elif number < 20:
        return int_under_20_to_str(number)
    else:
        tens, ones = divide_with_remainder(number, 10)
        if ones == 0:
            return TENS_NAMES[tens]
        else:
            return f"{TENS_NAMES[tens]}-{int_under_10_to_str(ones)}"

def int_under_20_to_str(number):
    if number < 10:
        return int_under_10_to_str(number)
    else:
        return TWEEN_AND_TEEN_NAMES[number - 10]


def int_under_10_to_str(number):
    return DIGIT_NAMES[number]

def divide_with_remainder(dividend, divisor):
    """Divides one number by another, using whole-number division. 
    Returns the quotient and the remainder. 
    """
    quotient = dividend // divisor
    remainder = dividend % divisor
    return quotient, remainder
    
